@@ -3,6 +3,7 @@ import re
 from typing import IO, List, Optional
 
 from unstructured.documents.elements import Element
+from unstructured.partition.common import exactly_one
 from unstructured.staging.base import dict_to_elements
 
 LIST_OF_DICTS_PATTERN = r"\A\s*\[\s*{"
@@ -14,22 +15,16 @@ def partition_json(
     text: Optional[str] = None,
 ) -> List[Element]:
     """Partitions an .json document into its constituent elements."""
-    if not any([filename, file, text]):
-        raise ValueError("One of filename, file, or text must be specified.")
+    exactly_one(filenmae=filename, file=file, text=text)
 
-    if filename is not None and not file and not text:
+    if filename is not None:
         with open(filename, encoding="utf8") as f:
             file_text = f.read()
-
-    elif file is not None and not filename and not text:
+    elif file is not None:
         file_text = file.read()
-
-    elif text is not None and not filename and not file:
+    elif text is not None:
         file_text = str(text)
 
-    else:
-        raise ValueError("Only one of filename, file, or text can be specified.")
-
     # NOTE(Nathan): we expect file_text to be a list of dicts (optimization)
     if not re.match(LIST_OF_DICTS_PATTERN, file_text):
         raise ValueError("Json schema does not match the Unstructured schema")
